pub enum ApcliGroupError {
InvalidShape(String),
ModeNotString(String),
ModeInvalid(String),
}Expand description
Errors surfaced by the fallible from_yaml builder.
Variants
InvalidShape(String)
apcli config was neither a boolean nor a mapping.
ModeNotString(String)
mode was not a string.
ModeInvalid(String)
mode was a string but not one of the allowed values.