Module output

Module output 

Functions

format_exec_result
Render a module execution result.
format_module_detail
Render a single module descriptor with its full schema.
format_module_list
Render a list of module descriptors as a table or JSON.
resolve_format
Determine the output format to use.