pub fn register_system_commands(cli: Command) -> CommandExpand description
Register system management subcommands on the root command.
Returns the command with health, usage, enable, disable, reload, and config subcommands appended. If the caller determines system modules are unavailable it may skip calling this function entirely.